LdpServer

Struct LdpServer 

pub struct LdpServer { /* private fields */ }
A minimal LDP server for testing and research.

Implementations

Source

impl LdpServer

pub fn new(identity: LdpIdentityCard, handler: TaskHandler) -> Self

Create a new LDP server with the given identity and task handler.

pub fn with_signing_secret(self, secret: impl Into<String>) -> Self

Set a signing secret for HMAC message signing (builder pattern).

pub fn echo_server(delegate_id: &str, name: &str) -> Self

Create a test server with an echo handler (returns input as output).

pub fn identity(&self) -> &LdpIdentityCard

Get the identity card.

pub fn handle_identity_request(&self) -> Value

Handle a GET /ldp/identity request.

pub fn handle_capabilities_request(&self) -> Value

Handle a GET /ldp/capabilities request.

pub async fn handle_message( &self, envelope: LdpEnvelope, ) -> Result<LdpEnvelope, String>

Handle a POST /ldp/messages request.

Processes the incoming LDP envelope and returns a response envelope.

pub async fn active_sessions(&self) -> usize

Get active session count.

pub async fn completed_tasks(&self) -> usize

Get completed task count.